#!/usr/bin/env python

import unittest

from podenco.domain.podcast import Podcast, Author, Episode
from podenco.repositories.yaml_repository import YamlRepository


class TestYamlRepository(unittest.TestCase):
    def setUp(self):
        self.author = Author(name="John Doe", email="john@doe.com")
        self.episode1 = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file="episode1.mp3",
        )
        self.episode2 = Episode(
            id=2,
            title="Episode 2",
            description="Episode 2: second test.",
            audio_file="episode2.mp3",
        )
        self.podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )

    def test_get(self):
        yaml_str = """---
podcast:
    title: Test podcast
    subtitle: Test podcast subtitle.
    description: Test podcast description.
    author:
        name: John Doe
        email: john@doe.com
    episodes:
        - title: Episode 1
          description: "Episode 1: test."
          audio_file: episode1.mp3
        - title: Episode 2
          description: "Episode 2: second test."
          audio_file: episode2.mp3
    base_url: https://example.com
"""
        repository = YamlRepository(yaml_str)
        result = repository.get()

        self.assertEqual(result, self.podcast)



#!/usr/bin/env python

import unittest
import unittest.mock as mock

from feedgen.feed import FeedGenerator

from podenco.domain.podcast import Podcast, Author, Episode
from podenco.serializers import podcast_serializer_rss as ser


class TestPodcastSerializerRSS(unittest.TestCase):
    def setUp(self):
        self.author = Author(name="John Doe", email="john@doe.com")
        self.episode1 = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file="episode1.mp3",
        )
        self.episode2 = Episode(
            id=2,
            title="Episode 2",
            description="Episode 2: second test.",
            audio_file="episode2.mp3",
        )
        self.podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )

    def tearDown(self):
        pass

    def test_podcast_serializer(self):
        output = ser.PodcastEnconderRSS.serialize(self.podcast)

        fg = FeedGenerator()
        fg.load_extension("podcast")
        # fg.podcast.itunes_category("Technology", "Podcasting")
        fg.title("Test podcast")
        fg.description("Test podcast description.")
        fg.author({"name": "John Doe", "email": "john@doe.com"})
        fg.link(href="https://example.com/podcast.atom", rel="self")
        fg.logo("https://example.com/podcast.jpg")

        for episode in (self.episode1, self.episode2):
            fe = fg.add_entry()
            media_url = "https://example.com/{}/audio.mp3".format(episode.id)
            fe.id(media_url)
            fe.title(episode.title)
            fe.description(episode.description)
            fe.enclosure(media_url, 0, "audio/mpeg")

        expected_output = fg.rss_str(pretty=False).decode("utf-8")

        self.assertEqual(output, expected_output)



#!/usr/bin/env python

import os
import tempfile

import unittest
import unittest.mock as mock

from podenco.domain.podcast import Podcast, Author, Episode
from podenco.serializers import podcast_serializer_rss as ser
from podenco.use_cases.podcast_generate import PodcastGenerate


class TestPodcastLoad(unittest.TestCase):
    def setUp(self):
        self.input_path = tempfile.TemporaryDirectory()

        tmp_dir = self.input_path.name

        with open(tmp_dir + "/episode1.mp3", "wb") as f:
            f.write(b"episode_1_mp3_content")

        with open(tmp_dir + "/episode2.mp3", "wb") as f:
            f.write(b"episode_2_mp3_content")

        self.author = Author(name="John Doe", email="john@doe.com")
        self.episode1 = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file=tmp_dir + "/episode1.mp3",
        )
        self.episode2 = Episode(
            id=2,
            title="Episode 2",
            description="Episode 2: second test.",
            audio_file=tmp_dir + "/episode2.mp3",
        )
        self.podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )

    def tearDown(self):
        self.input_path.cleanup()

    def test_podcast_generate(self):
        repo = mock.Mock()
        repo.get.return_value = self.podcast

        with tempfile.TemporaryDirectory() as tmpdirname:
            podcast_generate_use_case = PodcastGenerate(
                repository=repo, output_path=tmpdirname + "/podcast"
            )
            podcast_generate_use_case.execute()

            self.assertTrue(os.path.exists(tmpdirname + "/podcast"))

            with open(tmpdirname + "/podcast/podcast.rss") as f:
                rss_content = f.read()
                expected_output = ser.PodcastEnconderRSS.serialize(self.podcast)
                self.assertEqual(rss_content, expected_output)

            self.assertTrue(os.path.exists(tmpdirname + "/podcast/1/audio.mp3"))

            with open(tmpdirname + "/podcast/1/audio.mp3", "rb") as f:
                audio_content = f.read()
                self.assertEqual(audio_content, b"episode_1_mp3_content")

            self.assertTrue(os.path.exists(tmpdirname + "/podcast/2/audio.mp3"))

            with open(tmpdirname + "/podcast/2/audio.mp3", "rb") as f:
                audio_content = f.read()
                self.assertEqual(audio_content, b"episode_2_mp3_content")



#!/usr/bin/env python

import unittest
import unittest.mock as mock

from podenco.domain.podcast import Podcast, Author, Episode
from podenco.use_cases.podcast_load import PodcastLoad


class TestPodcastLoad(unittest.TestCase):
    def setUp(self):
        self.author = Author(name="John Doe", email="john@doe.com")
        self.episode1 = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file="episode1.mp3",
        )
        self.episode2 = Episode(
            id=2,
            title="Episode 2",
            description="Episode 2: second test.",
            audio_file="episode2.mp3",
        )
        self.podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )

    def tearDown(self):
        pass

    def test_case(self):
        repo = mock.Mock()
        repo.get.return_value = self.podcast

        podcast_load_use_case = PodcastLoad(repo)
        result = podcast_load_use_case.execute()

        repo.podcast.asset_called_with()
        self.assertEqual(result, self.podcast)



#!/usr/bin/env python
import unittest

from podenco.domain.podcast import Podcast, Author, Episode


class TestAuthor(unittest.TestCase):
    def test_init_author(self):
        author = Author(name="John Doe", email="john@doe.com")
        self.assertEqual(author.name, "John Doe")
        self.assertEqual(author.email, "john@doe.com")

    def test_author_to_dict(self):
        author = Author(name="John Doe", email="john@doe.com")
        self.assertEqual(
            author.to_dict(), {"name": "John Doe", "email": "john@doe.com"}
        )


class TestEpisode(unittest.TestCase):
    def test_init_episode(self):
        episode = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file="episode1.mp3",
        )
        self.assertEqual(episode.id, 1)
        self.assertEqual(episode.title, "Episode 1")
        self.assertEqual(episode.description, "Episode 1: test.")
        self.assertEqual(episode.audio_file, "episode1.mp3")


class TestPodcasts(unittest.TestCase):
    def setUp(self):
        self.author = Author(name="John Doe", email="john@doe.com")
        self.episode1 = Episode(
            id=1,
            title="Episode 1",
            description="Episode 1: test.",
            audio_file="episode1.mp3",
        )
        self.episode2 = Episode(
            id=2,
            title="Episode 2",
            description="Episode 2: second test.",
            audio_file="episode2.mp3",
        )

    def test_init_podcast(self):
        podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )
        self.assertEqual(podcast.title, "Test podcast")
        self.assertEqual(podcast.subtitle, "Test podcast subtitle.")
        self.assertEqual(podcast.description, "Test podcast description.")
        self.assertEqual(podcast.author, self.author)
        self.assertEqual(podcast.episodes, [self.episode1, self.episode2])
        self.assertEqual(podcast.base_url, "https://example.com")
        self.assertEqual(podcast.atom_url, "https://example.com/podcast.atom")
        self.assertEqual(podcast.rss_url, "https://example.com/podcast.rss")
        self.assertEqual(podcast.logo_url, "https://example.com/podcast.jpg")

    def test_episode_media_url(self):
        podcast = Podcast(
            title="Test podcast",
            subtitle="Test podcast subtitle.",
            description="Test podcast description.",
            author=self.author,
            episodes=[self.episode1, self.episode2],
            base_url="https://example.com",
        )
        self.assertEqual(
            podcast.episode_audio_url(self.episode1), "https://example.com/1/audio.mp3"
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `podenco` package."""


import unittest
from unittest.mock import patch, mock_open

from click.testing import CliRunner

from podenco.domain.podcast import Podcast, Author, Episode
from podenco.repositories.yaml_repository import YamlRepository
from podenco import cli


class Testpodenco(unittest.TestCase):
    """Tests for `podenco` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        help_result = runner.invoke(cli.main, ["--help"])
        assert help_result.exit_code == 0
        assert "--help  Show this message and exit." in help_result.output
        assert "generate  Generate static site file structure." in help_result.output

    @patch("podenco.cli.PodcastGenerate")
    def test_cli_generate(self, MockPodcastGenerate):
        """Test the CLI."""
        runner = CliRunner()

        yaml_str = """---
podcast:
    title: Test podcast
    subtitle: Test podcast subtitle.
    description: Test podcast description.
    author:
        name: John Doe
        email: john@doe.com
    episodes:
        - title: Episode 1
          description: "Episode 1: test."
          audio_file: episode1.mp3
        - title: Episode 2
          description: "Episode 2: second test."
          audio_file: episode2.mp3
    base_url: https://example.com
"""
        repository = YamlRepository(yaml_str)

        mock_podcast_generate = MockPodcastGenerate.return_value

        with patch("builtins.open", mock_open(read_data=yaml_str)) as yaml_file:
            result = runner.invoke(cli.generate, ["podcast.yaml", "/output/"])
            yaml_file.assert_called_with("podcast.yaml")

        MockPodcastGenerate.assert_called_once_with(repository, "/output/")
        mock_podcast_generate.execute.assert_called_once()

        assert result.exit_code == 0
        assert result.output == "Done!\n"



"""Console script for podenco."""

import click

from podenco.use_cases.podcast_generate import PodcastGenerate
from podenco.repositories.yaml_repository import YamlRepository


@click.command()
@click.argument("filename")
@click.argument("output_path")
def generate(filename, output_path):
    """Generate static site file structure."""
    with open(filename) as yaml_file:
        yaml_str = yaml_file.read()
    repository = YamlRepository(yaml_str)
    podcast_generate_uc = PodcastGenerate(repository, output_path)
    podcast_generate_uc.execute()
    click.echo("Done!")


@click.group()
def main(args=None):
    """Console script for podenco."""


main.add_command(generate)
